Loads the rr_list_gbd.xlsx file containing pathogen-drug combinations with relative risk values for burden estimation.
Examples
if (FALSE) { # \dontrun{
rr_data <- load_rr_reference()
head(rr_data)
} # }
Loads the rr_list_gbd.xlsx file containing pathogen-drug combinations with relative risk values for burden estimation.
if (FALSE) { # \dontrun{
rr_data <- load_rr_reference()
head(rr_data)
} # }