Prints a human-readable summary of which preprocessing steps can be run given the current data columns.
Arguments
- data
Data frame after column mapping. Or pass the result of
detect_preprocessing_capabilities()directly.
Prints a human-readable summary of which preprocessing steps can be run given the current data columns.
Data frame after column mapping. Or pass the result of
detect_preprocessing_capabilities() directly.